@@ -5,12 +5,11 @@
 #' of base R's \code{\link[base]{plot}} function that is used by
 #' \code{\link[TraMineR:seqplot]{TraMineR::seqplot}} \insertCite{gabadinho2011}{ggseqplot}.
 #'
-#' @eval shared_params()
+#' @inheritParams ggseqdplot
 #' @param barwidth specifies width of bars (default is \code{NULL}); valid range: (0, 1]
 #' @param no.n specifies if number of (weighted) sequences is shown (default is \code{TRUE})
 #' @param with.missing Specifies if missing states should be considered when computing the state distributions (default is \code{FALSE}).
 #' @param border if \code{TRUE} bars are plotted with black outline; default is \code{FALSE} (also accepts \code{NULL})
-#' @eval shared_facet()
 #'
 #' @details The function uses \code{\link[TraMineR:seqmodst]{TraMineR::seqmodst}}
 #' to obtain the modal states and their prevalence. This requires that the
@@ -52,7 +51,7 @@
 #' # with ggseqplot and some layout changes
 #' ggseqmsplot(actcal.seq, group = actcal$sex, no.n = TRUE, border = FALSE, facet_nrow = 2)
 #'
-#' @importFrom rlang .data
+#' @importFrom rlang .data %||%
 ggseqmsplot <- function(seqdata,
                         no.n = FALSE,
                         barwidth = NULL,
@@ -66,21 +65,21 @@ ggseqmsplot <- function(seqdata,
     stop("data is not a sequence object, use 'TraMineR::seqdef' to create one")
   }
 
-  if (!is.null(group) & (length(group) != nrow(seqdata))) {
+  if (!is.null(group) && (length(group) != nrow(seqdata))) {
     stop("length of group vector must match number of rows of seqdata")
   }
 
-  if (is.null(border)) border <- FALSE
+  border <- border %||% FALSE
 
-  if (!is.logical(weighted) | !is.logical(with.missing) |
-      !is.logical(border) | !is.logical(no.n)) {
+  if (!is.logical(weighted) || !is.logical(with.missing) ||
+      !is.logical(border) || !is.logical(no.n)) {
     stop("the arguments `no.n`, `weighted`, `with.missing`, and `border` have to be objects of type logical")
   }
 
 
   if (is.null(attributes(seqdata)$weights)) weighted <- FALSE
 
-  if ("haven_labelled" %in% class(group)) {
+  if (inherits(group, "haven_labelled")) {
     group_name <- deparse(substitute(group))
     group <- haven::as_factor(group)
     cli::cli_warn(c("i" = "group vector {.arg {group_name}} is of class {.cls haven_labelled} and has been converted into a factor"))
@@ -94,7 +93,7 @@ ggseqmsplot <- function(seqdata,
   }
   if (is.null(group)) grinorder <- factor(1)
 
-  if (is.null(group)) group <- 1
+  group <- group %||% 1
 
 
   if (!is.null(facet_ncol) && as.integer(facet_ncol) != facet_ncol) {
@@ -105,7 +104,7 @@ ggseqmsplot <- function(seqdata,
     stop("`facet_nrow` must be NULL or an integer.")
   }
 
-  if (!is.null(barwidth) && (barwidth <= 0 | barwidth > 1)) {
+  if (!is.null(barwidth) && (barwidth <= 0 || barwidth > 1)) {
     stop("`barwidth` must be NULL or a value in the range (0, 1]")
   }
 
@@ -133,7 +132,7 @@ ggseqmsplot <- function(seqdata,
                                  levels = TraMineR::alphabet(seqdata),
                                  labels = attributes(seqdata)$labels),
                   state = forcats::fct_na_value_to_level(.data$state,
-                                                          level = "Missing"
+                                                         level = "Missing"
                   ),
                   state = forcats::fct_drop(.data$state, "Missing"), # shouldn't be necessary
                   state = forcats::fct_rev(.data$state),
@@ -154,7 +153,7 @@ ggseqmsplot <- function(seqdata,
     dplyr::full_join(grouplabspec, by = "group")
 
 
-  if("Missing" %in% msplotdata$state == TRUE) {
+  if("Missing" %in% msplotdata$state) {
     cpal <- c(attributes(seqdata)$cpal,
               attributes(seqdata)$missing.color)
   } else {
