@@ -10,8 +10,8 @@ old <- options()
 on.exit(options(old))
 options(rmarkdown.html_vignette.check_title = FALSE)
 
-pkgs <- c("colorspace", "ggplot2", "ggthemes", "ggseqplot", "hrbrthemes", 
-          "patchwork", "purrr", "TraMineR")
+pkgs <- c("colorspace", "ggplot2", "ggthemes", "ggseqplot",
+          "patchwork", "forcats", "ggh4x", "purrr", "TraMineR")
 
 # Load all packages to library and adjust options
 lapply(pkgs, library, character.only = TRUE)
@@ -19,27 +19,33 @@ lapply(pkgs, library, character.only = TRUE)
 
 
 ## ----libraries, eval=FALSE----------------------------------------------------
-#  ## ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-#  ## Load and download (if necessary) required packages ----
-#  ## ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-#  
-#  
-#  ## Save package names as a vector of strings
-#  pkgs <- c("colorspace", "ggplot2", "ggthemes", "hrbrthemes",
-#            "patchwork", "purrr", "TraMineR")
-#  
-#  
-#  ## Install uninstalled packages
-#  lapply(pkgs[!(pkgs %in% installed.packages())],
-#         install.packages, repos = getOption("repos")["CRAN"])
-#  
-#  
-#  ## Load all packages to library and adjust options
-#  lapply(pkgs, library, character.only = TRUE)
-#  
-#  ## Don't forget to load ggseqplot
-#  library(ggseqplot)
-#  
+# ## ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+# ## Load and download (if necessary) required packages ----
+# ## ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+# 
+# 
+# ## Save package names as a vector of strings
+# pkgs <- c("colorspace", # for using colors palettes
+#           "forcats", # for dropping unused factor levels with `fct_drop`
+#           "ggh4x", # for proportional panel sized with `force_panelsizes`
+#           "ggplot2", # for using all the ggplot2 functions
+#           "ggthemes", # for getting access to the canva_palettes
+#           "patchwork", # for working with plot types built with patchwork
+#           "purrr", # used in the grouped rplot example
+#           "TraMineR") # the ultimate sequence analysis suite
+# 
+# 
+# ## Install uninstalled packages
+# lapply(pkgs[!(pkgs %in% installed.packages())],
+#        install.packages, repos = getOption("repos")["CRAN"])
+# 
+# 
+# ## Load all packages to library and adjust options
+# lapply(pkgs, library, character.only = TRUE)
+# 
+# ## Don't forget to load ggseqplot
+# library(ggseqplot)
+# 
 
 ## ----setup, message=FALSE-----------------------------------------------------
 
@@ -80,7 +86,6 @@ dplot <- ggseqdplot(actcal.seq)
 dplot$data
 
 ## ----dplot1-------------------------------------------------------------------
-# ggseqplot::ggseqdplot
 ggseqdplot(actcal.seq)
 
 ## ----message=FALSE, warning=FALSE---------------------------------------------
@@ -90,10 +95,14 @@ ggseqdplot(actcal.seq) +
   labs(title = "State distribution plot",
        x = "Month") +
   guides(fill=guide_legend(title="Alphabet")) +
-  theme_ipsum(base_family = "") + # ensures that this works on different OS
-  theme(plot.title = element_text(size = 30, 
-                                  margin=margin(0,0,20,0)),
-        plot.title.position = "plot")
+  theme_minimal(base_family = "") +
+  theme(plot.title = element_text(size = 30, margin=margin(0,0,20,0)),
+        plot.title.position = "plot",
+        axis.title.x = element_text(hjust = 1, 
+                                    vjust = -1),
+        axis.title.y = element_text(hjust = 1, 
+                                    vjust = 1),
+        axis.title = element_text(size = 9))
 
 ## ----message=FALSE, warning=FALSE---------------------------------------------
 # Save plot using weights
@@ -111,11 +120,16 @@ p2 <- ggseqdplot(ex1.seq,
 p1 + p2 + 
   plot_layout(guides = "collect") &
   scale_fill_manual(values= canva_palettes$`Fun and tropical`[1:4]) &
-  theme_ipsum(base_family = "") &
+  theme_minimal(base_family = "") &
   theme(plot.title = element_text(size = 20,
                                   hjust = 0.5),
         legend.position = "bottom",
-        legend.title = element_blank())
+        legend.title = element_blank(),
+        axis.title.x = element_text(hjust = 1, 
+                                    vjust = -1),
+        axis.title.y = element_text(hjust = 1, 
+                                    vjust = 1),
+        axis.title = element_text(size = 9))
 
 ## -----------------------------------------------------------------------------
 ggseqtrplot(actcal.seq, 
@@ -126,13 +140,13 @@ ggseqtrplot(actcal.seq,
 p1 <- ggseqtrplot(biofam.seq, 
                   dss = FALSE, 
                   x_n.dodge = 2,
-                  labsize = 3) +
+                  labsize = 7) +
   ggtitle("STS Sequences") +
   theme(plot.margin = unit(c(5,10,5,5), "points"))
 
 p2 <- ggseqtrplot(biofam.seq, 
                   x_n.dodge = 2,
-                  labsize = 3) +
+                  labsize = 7) +
     ggtitle("DSS Sequences") +
   theme(plot.margin = unit(c(5,5,5,10), "points"))
 
@@ -151,6 +165,21 @@ p1 + p2 &
   theme(plot.title = element_text(size = 20,
                                   hjust = 0.5))
 
+## -----------------------------------------------------------------------------
+# plot a subset of 5 sequences from biofam.seq
+ggseqiplot(biofam.seq[2:6,],
+           group = 1:5,
+           facet_ncol = 1,
+           strip.position = "left",
+           no.n = TRUE,
+           border = TRUE, 
+           weighted = FALSE) +
+  labs(y = NULL) +
+  theme(strip.text.y.left = element_text(angle = 0),
+        panel.spacing.y = unit(1.5, "lines"),
+        axis.text.y =  element_blank(),
+        axis.ticks.y = element_blank())
+
 ## -----------------------------------------------------------------------------
 ## default plot
 ggseqmtplot(actcal.seq, no.n = TRUE, error.bar = "SE") 
@@ -174,6 +203,19 @@ ggseqiplot(actcal.seq, sortv = "from.end") +
   coord_flip()
 
 
+## -----------------------------------------------------------------------------
+hghts <- table(fct_drop(actcal$sex)) / nrow(actcal.seq)
+
+## -----------------------------------------------------------------------------
+## use ggh4x::force_panelsizes to get proportional panels
+ggseqiplot(actcal.seq, 
+           sortv = "from.end", 
+           group = actcal$sex,
+           facet_ncol = 1) +
+  force_panelsizes(rows = hghts) +
+  theme(panel.spacing = unit(1, "lines"))
+
+
 ## -----------------------------------------------------------------------------
 ## compute dissimilarity matrix required for plot
 diss <- seqdist(biofam.seq, method = "LCS")
@@ -184,10 +226,15 @@ ggseqrfplot(biofam.seq, diss = diss, k = 12)
 
 ## adjusted version
 ggseqrfplot(biofam.seq, diss = diss, k = 12) &
-  theme_ipsum(base_family = "") &
+  theme_minimal(base_family = "") &
   theme(legend.position = "bottom",
         legend.title = element_blank(),
-        plot.title = element_text(size = 12)) &
+        plot.title = element_text(size = 12),
+        axis.title.x = element_text(hjust = 1, 
+                                    vjust = -1),
+        axis.title.y = element_text(hjust = 1, 
+                                    vjust = 1),
+        axis.title = element_text(size = 9)) &
   plot_annotation(title = "Relative Frequency Sequence Plot")
 
 ## -----------------------------------------------------------------------------
